@@ -153,26 +153,53 @@ class GitScribeServer:
         async def handle_call_tool(name: str, arguments: Dict[str, Any]) -> CallToolResult:
             """Handle tool calls."""
             try:
+                logger.info(f"Handling tool call: {name} with arguments: {arguments}")
+                
+                # For debugging - return a simple test result first
                 if name == "scrape_documentation":
-                    result = await self._scrape_documentation(arguments)
+                    # Test simple response
+                    simple_result = {
+                        "status": "success", 
+                        "message": "Test scraping response",
+                        "url": arguments.get("url", "")
+                    }
+                    result_text = f"Scraped documentation from {arguments.get('url', '')}"
+                    
                 elif name == "search_documentation":
                     result = await self._search_documentation(arguments)
+                    import json
+                    result_text = json.dumps(result, indent=2)
                 elif name == "get_code_examples":
                     result = await self._get_code_examples(arguments)
+                    import json
+                    result_text = json.dumps(result, indent=2)
                 else:
                     raise ValueError(f"Unknown tool: {name}")
                 
-                # Convert result to JSON string for clean output
-                import json
-                result_text = json.dumps(result, indent=2)
+                logger.info(f"Tool result text: {result_text[:200]}...")
                 
+                # Return with minimal structure
                 return CallToolResult(
-                    content=[TextContent(type="text", text=result_text)]
+                    content=[
+                        TextContent(
+                            type="text",
+                            text=result_text
+                        )
+                    ]
                 )
+                
             except Exception as e:
                 logger.error(f"Error calling tool {name}: {e}")
+                import traceback
+                traceback.print_exc()
+                
                 return CallToolResult(
-                    content=[TextContent(type="text", text=f"Error: {str(e)}")]
+                    content=[
+                        TextContent(
+                            type="text", 
+                            text=f"Error: {str(e)}"
+                        )
+                    ]
                 )
         
         @self.server.list_resources()
